==> haskell-regex-pcre-0.95.0.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-pcre
version:              0.95.0.0
visibility:           public
id:                   regex-pcre-0.95.0.0-3cDPip7vKTj7g2mO0lE0DD
key:                  regex-pcre-0.95.0.0-3cDPip7vKTj7g2mO0lE0DD
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             PCRE Backend for "Text.Regex" (regex-base)
description:
    This package provides a <http://pcre.org/ PCRE> backend for the <//hackage.haskell.org/package/regex-base regex-base> API.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  4b48f1b55fd4390de97d83461ab191e7
exposed:              True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap

hidden-modules:       Paths_regex_pcre
import-dirs:          /usr/lib/ghc-9.0.2/site-local/regex-pcre-0.95.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/regex-pcre-0.95.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/regex-pcre-0.95.0.0
hs-libraries:         HSregex-pcre-0.95.0.0-3cDPip7vKTj7g2mO0lE0DD
extra-libraries:      pcre
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    regex-base-0.94.0.2-9bnMACbSerDB0WfT2SIplq

haddock-interfaces:   /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html:         /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-pcre-0.95.0.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-pcre
version:              0.95.0.0
visibility:           public
id:                   regex-pcre-0.95.0.0-8JTNevh6vF7HTkboxZ55oR
key:                  regex-pcre-0.95.0.0-8JTNevh6vF7HTkboxZ55oR
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             PCRE Backend for "Text.Regex" (regex-base)
description:
    This package provides a <http://pcre.org/ PCRE> backend for the <//hackage.haskell.org/package/regex-base regex-base> API.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  8ab0dc0176a744bc7c5a4347abf3a59c
exposed:              True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap

hidden-modules:       Paths_regex_pcre
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-pcre-0.95.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-pcre-0.95.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-pcre
hs-libraries:         HSregex-pcre-0.95.0.0-8JTNevh6vF7HTkboxZ55oR
extra-libraries:      pcre
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN

haddock-interfaces:   /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html:         /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
